@@ -46,6 +46,7 @@
 #include "gdata-documents-presentation.h"
 #include "gdata-documents-folder.h"
 #include "gdata-documents-drawing.h"
+#include "gdata-documents-pdf.h"
 #include "gdata-types.h"
 #include "gdata-private.h"
 #include "gdata-service.h"
@@ -112,6 +113,8 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 			entry_type = GDATA_TYPE_DOCUMENTS_DOCUMENT;
 		} else if (g_strcmp0 (kind, "http://schemas.google.com/docs/2007#drawing") == 0) {
 			entry_type = GDATA_TYPE_DOCUMENTS_DRAWING;
+		} else if (g_strcmp0 (kind, "http://schemas.google.com/docs/2007#pdf") == 0) {
+			entry_type = GDATA_TYPE_DOCUMENTS_PDF;
 		} else {
 			g_message ("%s documents are not handled yet", kind);
 			g_free (kind);
