@@ -791,27 +791,8 @@ gdata_test_set_https_port (GDataMockServer *server)
 void
 gdata_test_mock_server_start_trace (GDataMockServer *server, const gchar *trace_filename)
 {
-	const gchar *ip_address;
-	GDataMockResolver *resolver;
-
 	gdata_mock_server_start_trace (server, trace_filename);
 	gdata_test_set_https_port (server);
-
-	if (gdata_mock_server_get_enable_online (server) == FALSE) {
-		/* Set up the expected domain names here. This should technically be split up between
-		 * the different unit test suites, but that's too much effort. */
-		ip_address = soup_address_get_physical (gdata_mock_server_get_address (server));
-		resolver = gdata_mock_server_get_resolver (server);
-
-		gdata_mock_resolver_add_A (resolver, "www.google.com", ip_address);
-		gdata_mock_resolver_add_A (resolver, "gdata.youtube.com", ip_address);
-		gdata_mock_resolver_add_A (resolver, "uploads.gdata.youtube.com", ip_address);
-		gdata_mock_resolver_add_A (resolver, "picasaweb.google.com", ip_address);
-		gdata_mock_resolver_add_A (resolver, "docs.google.com", ip_address);
-		gdata_mock_resolver_add_A (resolver, "lh3.googleusercontent.com", ip_address);
-		gdata_mock_resolver_add_A (resolver, "lh5.googleusercontent.com", ip_address);
-		gdata_mock_resolver_add_A (resolver, "lh6.googleusercontent.com", ip_address);
-	}
 }
 
 /**
